FastMBAR: A Fast Solver for Large Scale MBAR/UWHAM Equations
============================================================

The multistate Bennett acceptance ratio (MBAR) and unbinned weighted histogram analysis method (UWHAM) are
widely used approaches to calculate free energies of multiple thermodynamical states.
MBAR/UWHAM has several advantages comparing to the traditional WHAM method and 
is routinely used in alchemical free energy calculations, umbrella sampling, and
temperature/Hamiltonian replica exchange simulations to calculate relative free engines and potentials of mean force (PMF).

`FastMBAR` is a solver written in Python to solve large scale MBAR/UWHAM equations.
It can use both CPUs and GPUs.
To learn more about `FastMBAR`, please read the documentations at https://fastmbar.readthedocs.io
